/*
*  This script should be run after the cordova.js script and before every other script
* */

setDeviceInfo();
//setContentSecurityPolicyMetaTag();

function isLandscape() {
    let ret = true;

    var orientation = window.screen.orientation || window.screen.mozOrientation || window.screen.msOrientation || window.orientation;
    if (typeof (orientation) == 'undefined') {
        ret = true;
    } else if (typeof (orientation) == 'string') {
        // in ie edge
        ret = orientation.indexOf('landscape') >= 0;
    } else if (typeof (orientation) == 'number') {
        // on ios
        ret = (Math.abs(window.orientation) == 90);
    } else {
        if (typeof orientation.type != 'undefined') {
            ret = orientation.type.indexOf('landscape') >= 0;
        } else if (typeof orientation.angle != 'undefined') {
            ret = Math.abs(window.screen.orientation.angle) == 90;
        }
    }
    return ret;
}

function setDeviceInfo() {
    window.isMobile = false;
    window.isGtv = window.location.href.indexOf('gtv=true') > 0;
    window.onlyPortrait = false;
    window.onlyLandscape = false;

    // Safari: Must contain safari + must not contain chrome (https://developer.mozilla.org/en-US/docs/Web/HTTP/Browser_detection_using_the_user_agent)
    const isChrome = window.navigator.userAgent.indexOf('Chrome') > -1;
    window.isSafari = !isChrome && window.navigator.userAgent.indexOf('Safari') > -1;

    if (window.location.href.indexOf('forcemobile') > 0) {
        window.isMobile = true;
        window.onlyPortrait = true;
    } else if (window.location.href.indexOf('forcedesktop') > 0) {
        window.isMobile = false;
    } else if (/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(window.navigator.userAgent) ||
        (window.navigator.userAgent.match(/Macintosh/) && window.navigator.maxTouchPoints && window.navigator.maxTouchPoints > 2)) {

        if (window.cordova) {
            window.isMobile = true;
            window.onlyPortrait = true;
        } else {
            const heightInLandscape = window.isLandscape() ? window.innerHeight : window.innerWidth;

            // NOTE: In browser in devices.. If tablet (heightInLandscape >= 600) we should have onlyLandscape and desktop view..
            window.isTablet = heightInLandscape >= 600;
            window.isMobile = !window.isTablet;
            window.onlyPortrait = window.isMobile;
            window.onlyLandscape = !window.onlyPortrait;
        }
    }

    if (window.location.href.indexOf('widget=true') > 0) {
        window.isWidget = true;
        window.isMobile = true;
        window.onlyPortrait = true;
    }

    window.isDesktop = !window.isMobile;
}

function setContentSecurityPolicyMetaTag() {
    var isDevLocalhost = window.location.host === 'localhost:4200';
    if (isDevLocalhost) { return; }

    var cspMetaElement = document.createElement('meta');
    cspMetaElement.httpEquiv = "Content-Security-Policy";
    cspMetaElement.content =
        "default-src " +
            "'self' https://*.gameffective.me https://*.centrical.me " +
            "wss://*.gameffective.me wss://*.centrical.me " +
            "https://gameffective-res.cloudinary.com " +
            "https://*.pndsn.com https://*.pubnub.com " +
            "https://accessibilityserver.org " +
            "https://www.google.com https://www.gstatic.com " +
            "https://*.mxpnl.com https://*.mixpanel.com " +
            "https://*.getbeamer.com wss://*.getbeamer.com " +
            "https://*.userway.org https://*.googleapis.com " +
            "https://gameffective-media-us-east.s3.amazonaws.com " +
            "https://gameffective-media-eu.s3.amazonaws.com " +
            "https://gameffective-media-ap-south.s3.amazonaws.com " +
            "localhost:*; " +
        "style-src " +
            "'self' https://*.gameffective.me https://*.centrical.me " +
            "https://*.userway.org https://*.getbeamer.com " +
            "localhost:* " +
            "'unsafe-inline'; " +
        "font-src " +
            "'self' https://*.gameffective.me https://*.centrical.me " +
            "https://gameffective-res.cloudinary.com https://*.userway.org " +
            "https://fonts.gstatic.com " +
            "data:; " +
        "worker-src " +
            "'self' https://*.gameffective.me https://*.centrical.me " +
            "blob:; " +
        "media-src " +
            "'self' https://*.gameffective.me https://*.centrical.me " +
            "https://gameffective-res.cloudinary.com " +
            "https://accessibilityserver.org " +
            "https://*.getbeamer.com https://*.userway.org " +
            "localhost:* " +
            "data:; " +
        "frame-src *; " +
        "img-src * blob: data: android-webview-video-poster:;";

    document.getElementsByTagName('head')[0].appendChild(cspMetaElement);
}
